/**
 * A composable function to manage the theme of the application
 *
 * ## Example usage
 *
 * ```ts
 * const {
 *  mode,
 *  isDark,
 *  isContrast,
 *  toggleContrast,
 *  toggleDark,
 * } = useTheme()
 *
 * console.log(isDark.value) // false
 *
 * toggleDark()
 *
 * console.log(isDark.value) // true
 * ```
 */
export declare function useTheme(): {
    /**
     * The current theme mode
     */
    mode: import('@vueuse/core').UseColorModeReturn<"light" | "dark" | "contrastLight" | "contrastDark">;
    /**
     * Whether the current theme mode is dark theme
     */
    isDark: globalThis.ComputedRef<boolean>;
    /**
     * Whether the current theme mode is contrast theme
     */
    isContrast: globalThis.ComputedRef<boolean>;
    /**
     * Toggles the theme mode between light and dark theme
     */
    toggleDark: () => void;
    /**
     * Toggles the theme mode between contrast and no contrast theme
     */
    toggleContrast: () => void;
};
export default useTheme;
