import { Configuration } from '@azure/msal-browser';
import { InitOpts } from '@hotjar/browser/dist/utils';
import { Core as ClarityCore } from 'clarity-js';
import { TricklingOptions } from 'trickling';
import { Options as MarkdownOptions } from 'unplugin-vue-markdown/types';
import { SecondaryColor } from '../types';
export interface ModuleOptions {
    /**
     * The secondary color of the theme
     * @default 'innovative'
     */
    secondaryColor?: SecondaryColor;
    /**
     * Register all components for auto-import
     * @default true
     */
    components?: boolean;
    /**
     * Register all composables for auto-import
     * @default true
     */
    composables?: boolean;
    /**
     * Enable or disable or configure trickling progress bar
     * @default true
     */
    trickling?: boolean | TricklingOptions;
    /**
     * Enable or disable or configure clarity
     * @default true
     * @requires `clarity-js`
     */
    clarity?: boolean | ClarityCore.Config;
    /**
     * Enable or disable or configure hotjar
     * @default true
     * @requires `@hotjar/browser`
     */
    hotjar?: boolean | InitOpts;
    /**
     * Enable or disable or configure Markdown
     * @default true
     * @requires `unplugin-vue-markdown`
     */
    markdown?: boolean | MarkdownOptions;
    /**
     * Enable or disable or configure authentication
     * @default true
     * @requires `@azure/msal-browser`, `@faker-js/faker` (for offline-development)
     */
    auth?: boolean | AuthOptions;
    /**
     * Enable or disable or configure API
     * @default true
     * @requires `miragejs`
     */
    api?: boolean | APIOptions;
}
export interface AuthOptions {
    /**
     * MSAL configuration
     * @requires `@azure/msal-browser`, `@faker-js/faker` (for offline-development)
     */
    msal?: Configuration;
}
export interface APIOptions {
    /**
     * Mocked API server configuration. Used in `offline-development` mode as well as in vitest.
     * A path to the mock server file or a configuration object. If a path is provided, the referenced file should **export default** a config object.
     * @example
     * ```ts
     * export default defineMockServer({
     *  routes() {
     *    this.get('/widgets', () => ({
     *     widgets: [
     *       { id: 1, name: 'Widget 1' },
     *       { id: 2, name: 'Widget 2' },
     *     ],
     *    }))
     *  }
     * })
     * ```
     */
    mockServerPath?: string;
}
export declare const devServer: {
    host: string;
    port: number;
    https: false | {
        key: string;
        cert: string;
    };
    loadingTemplate: () => string;
};
declare const _default: import('@nuxt/schema').NuxtModule<ModuleOptions, ModuleOptions, false>;
export default _default;
