export interface NotificationOptions {
    /**
     * The unique identifier for the notification. If not provided, a random ID will be generated
     */
    id?: string;
    /**
     * The message to display in the notification
     */
    message: string;
    /**
     * The type of notification
     * @default 'default'
     */
    type?: NotificationType;
    /**
     * Action to take when the notification is clicked
     */
    onClick?: () => void;
    /**
     * Category name for the notification. Used to assign custom slot contents to notifications
     */
    category?: string;
    /**
     * Whether the notification should not disappear after a timeout. If `true`, it would need to be dismissed manually.
     * @default `type` === 'pending' ? true : false
     */
    persistent?: boolean;
}
export type Notification = NotificationOptions & {
    id: string;
    timer?: ReturnType<typeof setTimeout>;
};
export type NotificationType = 'info' | 'success' | 'warning' | 'error' | 'pending' | 'default';
export type SecondaryColor = 'innovative' | 'approachable' | 'professional' | 'contemporary' | 'dynamic' | 'complimentary';
export type AppEnvironment = 'development' | 'uat' | 'production' | 'local-development' | 'offline-development' | 'train';
export interface BaseFilter {
    name: string;
    label?: string;
}
export interface TextFilter {
    type: 'text';
    items: {
        name: string;
        value: string;
    }[];
}
export interface DateFilter {
    type: 'date';
}
export type Filter = BaseFilter & (TextFilter | DateFilter);
export interface BaseActiveFilter {
    name: string;
}
export interface TextActiveFilter {
    type: 'text';
    value: string;
}
export interface DateActiveFilter {
    type: 'date';
    value: {
        from: string;
        to: string;
    };
}
export type ActiveFilter = BaseActiveFilter & (TextActiveFilter | DateActiveFilter);
export type FileType = (File & {
    name: string;
}) | (File & {
    name: string;
})[] | undefined;
export interface FieldSchema<TKey extends string = string, TRaw = any, T = any> {
    /**
     * The name of the field in the data object
     */
    name: TKey;
    /**
     * The type of the field
     * @values `text`, `date`
     * @default `text`
     */
    type?: 'text' | 'date';
    /**
     * The label to display for the field
     */
    label?: string;
    /**
     * A function to get the value to display in collection.
     * Also used for matching against search if present.
     * @param value The value to get the label for
     * @returns The label to display in the table
     */
    getDisplayValue?: (value: TRaw) => string;
    /**
     * A function to get the value to use in the table.
     * Also used for comparison in sorting if present.
     * @param rawValue The raw value from the data object
     * @returns The value to use in the table
     */
    getValue?: (rawValue: TRaw) => T;
}
export type SortDirection = 'asc' | 'desc' | null;
export { type Crumb } from './components/AppBreadcrumbs.vue';
export { type AppButtonVariant as WButtonVariant } from './components/AppButton.vue';
export { type AppTooltipPosition as WTooltipPosition } from './components/AppTooltip.vue';
export type RouteLocationRaw = string | {
    name?: string;
    path?: string;
    hash?: string;
    replace?: boolean;
    params?: Record<string, string | number>;
    query?: Record<string, string>;
};
export type LocationQueryRaw = Record<string | number, LocationQueryValueRaw | LocationQueryValueRaw[]>;
export type LocationQueryValueRaw = string | null | number | undefined;
